// src/index.tsx
import * as echarts from "echarts";

// src/EChartsCore.tsx
import { createEffect, onMount, onCleanup } from "solid-js";
import { createResizeObserver } from "@solid-primitives/resize-observer";
import { debounce } from "@solid-primitives/scheduled";

// src/utils.ts
var typeIsString = (value) => typeof value === "string" || value instanceof String;
var typeIsFunction = (value) => typeof value === "function";

// src/EChartsCore.tsx
var SolidEChartsCore = (props) => {
  let echartsRef;
  let chartRef;
  let isFirstResize = true;
  onMount(() => {
    chartRef = props.echarts.init(echartsRef, props.theme, props.opts);
    bindEvents(chartRef, props.createEvents ?? {});
    createResizeObserver(echartsRef, (_, el) => {
      if (el === echartsRef)
        resizeChart();
    });
  });
  onCleanup(() => {
    disposeChart();
  });
  createEffect(() => {
    const instance = getEchartsInstance();
    instance?.setOption(props.option, props.notMerge, props.lazyUpdate);
    if (props.showLoading) {
      instance?.showLoading(props.loadingOption);
    } else {
      instance?.hideLoading();
    }
  });
  const resizeChart = debounce(
    () => {
      const instance = getEchartsInstance();
      if (!isFirstResize && instance) {
        try {
          instance.resize({
            width: "auto",
            height: "auto"
          });
        } catch (e) {
          console.warn(e);
        }
      }
      isFirstResize = false;
    },
    props.debouncedResize ? 250 : 0
  );
  const disposeChart = () => {
    if (echartsRef) {
      props.echarts.dispose(echartsRef);
    }
  };
  const getEchartsInstance = () => {
    if (echartsRef) {
      return props.echarts.getInstanceByDom(echartsRef);
    }
    return void 0;
  };
  const bindEvents = (instance, events) => {
    for (const [eventType, eventCallback] of Object.entries(events ?? {})) {
      if (typeIsString(eventType) && typeIsFunction(eventCallback)) {
        instance.on(eventType, (parameters) => {
          eventCallback(parameters, instance);
        });
      } else {
        console.warn(
          "The event passed in must be a string, and the callback must be a function.",
          eventType,
          eventCallback
        );
      }
    }
  };
  const style = { height: "400px", width: "100%", ...props.style };
  return <div style={style} ref={echartsRef} class={props.class} />;
};
var EChartsCore_default = SolidEChartsCore;

// src/index.tsx
var SolidECharts = (props) => {
  return <EChartsCore_default {...props} echarts={echarts} />;
};
export {
  EChartsCore_default as SolidEChartsCore,
  SolidECharts as default
};
